import * as _tailwindcss_mangle_config from '@tailwindcss-mangle/config';
import { MangleUserConfig } from '@tailwindcss-mangle/config';
import { ClassGenerator } from '@tailwindcss-mangle/shared';
export { ClassGenerator } from '@tailwindcss-mangle/shared';
import postcss from 'postcss';
import * as MagicString from 'magic-string';
import MagicString__default from 'magic-string';
import { StringLiteral, TemplateElement } from '@babel/types';

interface InitConfigOptions {
    cwd?: string;
    classList?: string[];
    mangleOptions?: MangleUserConfig;
}
declare class Context {
    options: MangleUserConfig;
    private includeMatcher;
    private excludeMatcher;
    replaceMap: Map<string, string>;
    classSet: Set<string>;
    classGenerator: ClassGenerator;
    preserveFunctionSet: Set<string>;
    preserveClassNamesSet: Set<string>;
    preserveFunctionRegexs: RegExp[];
    constructor();
    isPreserveClass(className: string): boolean;
    addPreserveClass(className: string): Set<string>;
    isPreserveFunction(calleeName: string): boolean;
    private mergeOptions;
    isInclude(file: string): boolean;
    currentMangleClassFilter(className: string): boolean;
    getClassSet(): Set<string>;
    getReplaceMap(): Map<string, string>;
    addToUsedBy(key: string, file: string): void;
    loadClassSet(classList: string[]): void;
    initConfig(opts?: InitConfigOptions): Promise<_tailwindcss_mangle_config.UserConfig>;
}

interface IClassGeneratorContextItem {
    name: string;
    usedBy: string[];
}
interface IClassGeneratorOptions {
    reserveClassName?: (string | RegExp)[];
    customGenerate?: (original: string, opts: IClassGeneratorOptions, context: Record<string, any>) => string | undefined;
    log?: boolean;
    exclude?: (string | RegExp)[];
    include?: (string | RegExp)[];
    ignoreClass?: (string | RegExp)[];
    classPrefix?: string;
}
interface IHandlerOptions {
    ctx: Context;
}
interface IHtmlHandlerOptions extends IHandlerOptions {
    isVue?: boolean;
}
interface IJsHandlerOptions extends IHandlerOptions {
    splitQuote?: boolean;
    minified?: boolean;
}
interface IVueHandlerOptions extends IHandlerOptions {
}
interface ICssHandlerOptions extends IHandlerOptions {
    ignoreVueScoped?: boolean;
    file?: string;
}
interface IPreProcessJsOptions extends IHandlerOptions {
    code: string | MagicString__default;
    id: string;
}

declare function cssHandler(rawSource: string, options: ICssHandlerOptions): postcss.LazyResult<postcss.Root>;

declare function htmlHandler(raw: string | MagicString__default, options: IHtmlHandlerOptions): string;

declare function preProcessJs(options: IPreProcessJsOptions): string;
declare function preProcessRawCode(options: IPreProcessJsOptions): string;

declare function handleValue(raw: string, node: StringLiteral | TemplateElement, options: IJsHandlerOptions, ms: MagicString__default, offset: number, escape: boolean): string;
declare function jsHandler(rawSource: string | MagicString__default, options: IJsHandlerOptions): {
    code: string;
    readonly map: MagicString.SourceMap;
};

declare function vueHandler(raw: string | MagicString__default, options: IVueHandlerOptions): string;

export { Context, type IClassGeneratorContextItem, type IClassGeneratorOptions, type ICssHandlerOptions, type IHandlerOptions, type IHtmlHandlerOptions, type IJsHandlerOptions, type IPreProcessJsOptions, type IVueHandlerOptions, cssHandler, handleValue, htmlHandler, jsHandler, preProcessJs, preProcessRawCode, vueHandler };
